__version__ = '0.1.0'
import webbrowser
def google(What_do_you_want_to_google):
    webbrowser.open("https://www.google.com/search?q=" + What_do_you_want_to_google)
